@@ -23,6 +23,7 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.List;
 
+import javax.swing.JButton;
 import javax.swing.JLabel;
 import javax.swing.JOptionPane;
 import javax.swing.JPanel;
@@ -40,6 +41,7 @@ import mobac.gui.gpxtree.GpxEntry;
 import mobac.gui.gpxtree.GpxRootEntry;
 import mobac.gui.gpxtree.TrkEntry;
 import mobac.gui.gpxtree.TrksegEntry;
+import mobac.gui.mapview.layer.MapAreaHighlightingLayer;
 import mobac.program.interfaces.AtlasInterface;
 import mobac.program.interfaces.MapInterface;
 import mobac.program.interfaces.MapSource;
@@ -57,8 +59,10 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 
 	public static final AddGpxTrackPolygonMap INSTANCE = new AddGpxTrackPolygonMap();
 
+	private MapAreaHighlightingLayer msl = null;
+
 	public void actionPerformed(ActionEvent event) {
-		MainGUI mg = MainGUI.getMainGUI();
+		final MainGUI mg = MainGUI.getMainGUI();
 		GpxEntry entry = mg.gpxPanel.getSelectedEntry();
 
 		if (entry == null)
@@ -72,7 +76,8 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 			GpxRootEntry re = (GpxRootEntry) entry;
 			List<TrkType> tlist = re.getLayer().getGpx().getTrk();
 			if (tlist.size() > 1) {
-				JOptionPane.showMessageDialog(mg, I18nUtils.localizedStringForKey("msg_add_gpx_polygon_too_many_track"));
+				JOptionPane
+						.showMessageDialog(mg, I18nUtils.localizedStringForKey("msg_add_gpx_polygon_too_many_track"));
 				return;
 			} else if (tlist.size() == 1)
 				t = tlist.get(0);
@@ -81,14 +86,14 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 			t = ((TrkEntry) entry).getTrk();
 		if (t != null) {
 			if (t.getTrkseg().size() > 1) {
-				JOptionPane.showMessageDialog(mg, I18nUtils.localizedStringForKey("msg_add_gpx_polygon_too_many_segment"));
+				JOptionPane.showMessageDialog(mg,
+						I18nUtils.localizedStringForKey("msg_add_gpx_polygon_too_many_segment"));
 				return;
 			} else if (t.getTrkseg().size() == 1)
 				trk = t.getTrkseg().get(0);
 		}
 		if (trk == null) {
-			JOptionPane.showMessageDialog(mg, 
-					I18nUtils.localizedStringForKey("msg_add_gpx_polygon_no_select"), 
+			JOptionPane.showMessageDialog(mg, I18nUtils.localizedStringForKey("msg_add_gpx_polygon_no_select"),
 					I18nUtils.localizedStringForKey("Error"), JOptionPane.ERROR_MESSAGE);
 			return;
 		}
@@ -97,7 +102,7 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 		final String mapNameFmt = "%s %02d";
 		AtlasInterface atlasInterface = jAtlasTree.getAtlas();
 		String name = mg.getUserText();
-		MapSource mapSource = mg.getSelectedMapSource();
+		final MapSource mapSource = mg.getSelectedMapSource();
 		SelectedZoomLevels sZL = mg.getSelectedZoomLevels();
 		int[] zoomLevels = sZL.getZoomLevels();
 		if (zoomLevels.length == 0) {
@@ -105,7 +110,7 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 			return;
 		}
 		List<? extends GpxPoint> points = trk.getTrkpt();
-		EastNorthCoordinate[] trackPoints = new EastNorthCoordinate[points.size()];
+		final EastNorthCoordinate[] trackPoints = new EastNorthCoordinate[points.size()];
 		EastNorthCoordinate minCoordinate = new EastNorthCoordinate(Double.POSITIVE_INFINITY, Double.POSITIVE_INFINITY);
 		EastNorthCoordinate maxCoordinate = new EastNorthCoordinate(Double.NEGATIVE_INFINITY, Double.NEGATIVE_INFINITY);
 		for (int i = 0; i < trackPoints.length; i++) {
@@ -128,6 +133,8 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 
 		final UnitSystem unitSystem = Settings.getInstance().getUnitSystem();
 
+		final TileImageParameters customTileParameters = mg.getSelectedTileImageParameters();
+
 		JPanel panel = new JPanel(new BorderLayout());
 		panel.setPreferredSize(new Dimension(300, 100));
 		final JLabel label = new JLabel("");
@@ -143,19 +150,46 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 					d /= unitSystem.unitFactor;
 					unitName = unitSystem.unitLarge;
 				}
-				label.setText(String.format(I18nUtils.localizedStringForKey("dlg_gpx_track_select_distance"), ((int) d), unitName));
+				label.setText(String.format(I18nUtils.localizedStringForKey("dlg_gpx_track_select_distance"),
+						((int) d), unitName));
 			}
 		};
+		final JButton previewButton = new JButton(I18nUtils.localizedStringForKey("dlg_gpx_track_select_preview"));
+		previewButton.addActionListener(new ActionListener() {
+
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				int distance = slider.getValue();
+				MapPolygon maxZoomMap = MapPolygon.createTrackEnclosure(null, "Dummy", mapSource, maxZoom, trackPoints,
+						distance, customTileParameters);
+				if (msl != null)
+					msl.setObject(maxZoomMap);
+				msl = new MapAreaHighlightingLayer(maxZoomMap);
+				mg.previewMap.repaint();
+			}
+		});
+
 		cl.stateChanged(null);
 		slider.addChangeListener(cl);
 		panel.add(label, BorderLayout.NORTH);
 		panel.add(slider, BorderLayout.CENTER);
+		panel.add(previewButton, BorderLayout.SOUTH);
+
+		int result = JOptionPane.showConfirmDialog(mg, panel,
+				I18nUtils.localizedStringForKey("dlg_gpx_track_select_title"), JOptionPane.OK_CANCEL_OPTION);
+
+		if (msl != null) {
+			mg.previewMap.mapLayers.remove(msl);
+			msl.setObject(null);
+		}
 
-		int result = JOptionPane.showConfirmDialog(mg, panel, I18nUtils.localizedStringForKey("dlg_gpx_track_select_title"),
-				JOptionPane.OK_CANCEL_OPTION);
 		if (result != JOptionPane.OK_OPTION)
 			return;
 
+		int distance = slider.getValue();
+		MapPolygon maxZoomMap = MapPolygon.createTrackEnclosure(null, "Dummy", mapSource, maxZoom, trackPoints,
+				distance, customTileParameters);
+
 		String layerName = name;
 		int c = 1;
 		Layer layer = null;
@@ -169,19 +203,12 @@ public class AddGpxTrackPolygonMap implements ActionListener {
 			}
 		} while (!success);
 
-		TileImageParameters customTileParameters = mg.getSelectedTileImageParameters();
-
-		int distance = slider.getValue();
-		MapPolygon maxZoomMap = MapPolygon.createFromTrack(null, "Dummy", mapSource, maxZoom, trackPoints, distance,
-				customTileParameters);
-
 		int width = maxZoomMap.getMaxTileCoordinate().x - maxZoomMap.getMinTileCoordinate().x;
 		int height = maxZoomMap.getMaxTileCoordinate().y - maxZoomMap.getMinTileCoordinate().y;
 		if (Math.max(width, height) > Settings.getInstance().maxMapSize) {
 			String msg = I18nUtils.localizedStringForKey("msg_add_gpx_polygon_maxsize");
-			result = JOptionPane.showConfirmDialog(mg, msg, 
-					I18nUtils.localizedStringForKey("msg_add_gpx_polygon_maxsize_title"), 
-					JOptionPane.YES_NO_OPTION,
+			result = JOptionPane.showConfirmDialog(mg, msg,
+					I18nUtils.localizedStringForKey("msg_add_gpx_polygon_maxsize_title"), JOptionPane.YES_NO_OPTION,
 					JOptionPane.QUESTION_MESSAGE);
 			if (result != JOptionPane.YES_OPTION)
 				return;
