@@ -26,7 +26,8 @@ public interface LayerInterface extends AtlasObject, Iterable<MapInterface>, Cap
 
 	public AtlasInterface getAtlas();
 
-	public int calculateTilesToDownload();
+	public long calculateTilesToDownload();
 
 	public LayerInterface deepClone(AtlasInterface atlas);
+
 }
